searchData={"content_type":"text/markdown","items":[{"doc":"","ref":"RetryOn.html","title":"RetryOn","type":"module"},{"doc":"","ref":"RetryOn.html#retry_on_stale/2","title":"RetryOn.retry_on_stale/2","type":"function"},{"doc":"","ref":"RetryOn.html#retry_on_unique_constraint/4","title":"RetryOn.retry_on_unique_constraint/4","type":"function"},{"doc":"# RetryOn\r\n\r\n## `retry_on_stale/2`\r\n\r\n`retry_on_stale/2` performs an operation that might raise an `Ecto.StaleEntryError` error and retries\r\nit a specified number of times with a delay between each attempt.","ref":"readme.html","title":"RetryOn","type":"extras"},{"doc":"The example features a wallet's `balance_amount`, protected by [optimistic locking](https://hexdocs.pm/ecto/Ecto.Changeset.html#optimistic_lock/3) to prevent race conditions. The `retry_on_stale/2` function handles `Ecto.StaleEntryError` from concurrent transactions, refetching the wallet and retrying the operation.\r\n\r\n```elixir\r\nimport RetryOn, only: [retry_on_stale: 2]\r\n\r\ndef increase_wallet_balance(%Wallet{} = wallet, amount) do\r\n  retry_on_stale(\r\n    fn attempt ->\r\n      # refetch the latest wallet data for subsequent attempts\r\n      wallet = if attempt == 1, do: wallet, else: Repo.get!(Wallet, wallet.id)\r\n\r\n      # this function could raise a StaleEntryError\r\n      do_increase_wallet_balance(wallet, amount)\r\n    end,\r\n    max_attempts: 5, delay_ms: 100\r\n  )\r\nend\r\n\r\ndefp do_increase_wallet_balance(%Wallet{} = wallet, amount) do\r\n  new_balance = Decimal.add(wallet.balance_amount, amount)\r\n\r\n  wallet\r\n  |> Ecto.Changeset.change(balance_amount: new_balance)\r\n  |> Ecto.Changeset.optimistic_lock(:lock_version)\r\n  |> Repo.update!()\r\nend\r\n```","ref":"readme.html#example","title":"Example - RetryOn","type":"extras"},{"doc":"`:max_attempts` - The maximum number of attempts to perform the operation\r\nbefore giving up and re-raising the last `Ecto.StaleEntryError`.\r\n\r\n`:delay_ms` - The delay in milliseconds between each attempt.\r\n\r\n## `retry_on_unique_constraint/3`\r\n\r\n`retry_on_unique_constraint/3` performs an operation that might raise an `Ecto.UniqueConstraintError` error and retries\r\nit a specified number of times with a delay between each attempt.","ref":"readme.html#options","title":"Options - RetryOn","type":"extras"},{"doc":"```elixir\r\nimport RetryOn, only: [retry_on_unique_constraint: 2]\r\n\r\nretry_on_unique_constraint(\r\n  :my_field,\r\n  fn _ ->\r\n    # Code that performs an operation which may result in a unique constraint error on `:my_field`.\r\n    # The function is retried if a unique constraint error is found in a `{:error, changeset}` tuple or\r\n    # an `%Ecto.InvalidChangesetError{changeset: changeset}` error.\r\n  end,\r\n  max_attempts: 2, delay_ms: 500\r\n)\r\n```","ref":"readme.html#example","title":"Example - RetryOn","type":"extras"},{"doc":"`:max_attempts` - The maximum number of attempts to perform the operation\r\nbefore giving up and re-raising the last Ecto.StaleEntryError.\r\n\r\n`:delay_ms` - The delay in milliseconds between each attempt.","ref":"readme.html#options","title":"Options - RetryOn","type":"extras"},{"doc":"Add `retry_on` for Elixir as a dependency in your `mix.exs` file:\r\n\r\n```elixir\r\ndef deps do\r\n  [\r\n    {:retry_on, \"~> 0.1.0\"}\r\n  ]\r\nend\r\n```","ref":"readme.html#installation","title":"Installation - RetryOn","type":"extras"},{"doc":"HexDocs documentation can be found at [https://hexdocs.pm/retry_on](https://hexdocs.pm/retry_on).","ref":"readme.html#hexdocs","title":"HexDocs - RetryOn","type":"extras"}]}